% ===========================================================================
% Copyright (C):
%       2003-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Description   : ETSI SpM performance simulations
%
% Project       : BANG, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% Reference:
%    
% CVS:       $Id: SpM.m,v 1.2 2005/01/04 10:25:12 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2003-11-11 (ToNo) Created
%      2004-01-14 (ToNo) Simulation of reference scenarios completed
%      2005-01-14 (ToNo) Split up into smaller parts
%% ===========================================================================
global ex;

%% ===========================================================================
% Logging, print, saving and plot options
format compact;

maxplotf  = 12.5e6;     % Max frequency to plot
set(0,'DefaultLineLineWidth',2);
set(0,'DefaultTextFontSize',14);
set(0,'DefaultAxesFontSize',14);


%% ===========================================================================
% ETSI default inclusions

ex.param    = setupParam;                      % Some basic parameters

[ex.tfplist, ex.param.HAMBandName] = ...
	etsi_tfplanHAM([]);                    % Need a HAM band definition

ex.tfplist  = etsi_tfplansSDSL(ex.tfplist);    % Get ETSI SDSL plans
ex.tfplist  = etsi_tfplansSDSL_RC(ex.tfplist);    % Get ETSI SDSL plans
ex.tfplist  = etsi_tfplansADSL(ex.tfplist);    % Get ETSI ADSL plans
ex.tfplist  = etsi_masksVDSL(ex.tfplist);      % Get ETSI VDSL PSD masks
ex.tfplist  = etsi_tfplansVDSL(ex.tfplist);    % Get ETSI VDSL plans
ex.tfplist  = etsi_tfplansLegacy(ex.tfplist);  % Get ETSI ISDN and HDSL
ex.tfplist  = itu_tfplansADSL2(ex.tfplist);    % Get ITU ADSL2 plans
ex.tfplist  = etsi_tfplansESDSL(ex.tfplist);   % Get ETSI E-SDSL plans

ex.lclist   = setupLClist;                     % Line code definition (theor.
ex.lclist   = etsi_lcdefsSDSL(ex.lclist);      % ETSI Line code defs (SDSL)
ex.lclist   = etsi_lcdefsSDSL_SpecificRates(ex.lclist);  % and specific rates
ex.lclist   = etsi_lcdefsSDSL_SpecificRates_RC(ex.lclist);  % and specific rates
ex.lclist   = etsi_lcdefsADSL(ex.lclist);      % ETSI Line code defs (ADSL)
ex.lclist   = etsi_lcdefsVDSL(ex.lclist);      % ETSI Line code defs (VDSL)
ex.lclist   = etsi_lcdefsHDSL(ex.lclist);      % ETSI Line code defs (HDSL)
ex.lclist   = etsi_lcdefsISDN(ex.lclist);      % ETSI Line code defs (ISDN)
ex.lclist   = itu_lcdefsADSL2(ex.lclist);      % ITU  Line code defs (ADSL2)
ex.lclist   = etsi_lcdefsESDSL(ex.lclist);     % ETSI Line code defs (SDSL)

ex.clist    = etsi_cablesVDSL([]);             % Get ETSI (and ANSI) cables;


% Fix deeper HAM band notches
hb = getList(ex.tfplist, ex.param.HAMBandName);
hb.PSD.downstream = strrep(hb.PSD.downstream,'-80','-140');
hb.PSD.upstream   = strrep(hb.PSD.upstream,  '-80','-140');
ex.tfplist = setList(ex.tfplist,hb.name,hb);


%% ========================================================================
% Change default parameter values

% General parameters
ex.param.frequency.fastcalc  = 1;      % Use the fast frequency plan
ex.param.frequency.max       = 30e6;   % Max frequency in use (for masks etc.)
ex.param.XTlevel.NEXTx4      = 1;      % Flag to use forth order next modeling
ex.param.bgNoise.LT          = '-160'; % Backgound noise at LT (dBm/Hz)
ex.param.bgNoise.NT          = '-160'; % Backgound noise at NT (dBm/Hz)
ex.param.Zterm               = 135;    % VDSL is using 100 Ohm but not for s21!


%% ========================================================================
% Decide what frequency axis to use (after setting up ex.tfplist

df = 4.3125e3;           % Carrier spacing in Hz

if ex.param.frequency.fastrecalc,
    % Add VDSL band transition frequencies
    gbsize = 250e3;
    bandtrans = [3e6 3.75e6 5.1e6 5.2e6 7.05e6 8.5e6 ] ;
    tmp=[bandtrans-gbsize/2 bandtrans+gbsize/2 ];
    tmp = [tmp 1.5e6  ];
    % ADSL2 steps in PSD
    adsl2steps = [138e3 254e3 276e3]; 
    tmp=[tmp adsl2steps];
    tmp = [tmp+1 tmp tmp-1];

    % SDSL and HDSL dips and cross over points
    tmp = [tmp 100:100:40e3];
%    tmp = [tmp 50:50:2e6]; % Do a very fine grain simulation
    sdslcrossings = [1.2301e6 1.2302e6 1.3689e6 1.369e6];
    hdsldips = [584000:584000:584000*8  233600:233600:233600*8 90e3:90e3:8*90e3];
    factor=1e-3; hdslripple=hdsldips'*[ 1-5*factor:factor:1+5*factor];
    tmp=[tmp hdslripple(:)' sdslcrossings];
    % Add some high freq. points
    tmp = [tmp 1e6:100e3:18e6 19e6:1e6:30e6]; 
else
    error('OPS I think we need fastrecalc')
end;
% f is set once and do not change for each experiment
ex.param.frequency.f = union(getMinFreqaxis(ex.param.frequency.max),tmp);
ex.param.frequency.set = 1; 

f=ex.param.frequency.f; 


%% ========================================================================
% Set up the default reaches

    defreflen_HPM = [  3520  2440  2880  2880  1500 ];
    defreflen_HPR_VCC = [  6080  4560  3210  2140  2960  1500 ];
    defreflen_MPP_VCC = [  7150  5420  4060  2820  3260  1500 ];
    defreflen_MPP = [  4200  2820  3270  1500 ];
    defreflen_MPI = [  4300  2780  3380  1500 ];
    defreflen_MPM = [  4020  2840  3280  1500 ];
