function models = getNoiseModels()
%% ===========================================================================
%getNoiseModels - Gets all available noise models for an experiment setup.
%
% Returns:      models	List of (predefined) noise models that can be used
%
% Example(s):
%   mod = getNoiseModels; returns an array of strings containing available 
%   model names
%
% Algorithmic details:
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
%
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: getNoiseModels.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-01-05 (ToNo) Created
%      2000-03-13 (ToNo) Now dynamicly calculates the possible noise models
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%% ===========================================================================
global ex;

% Note this assumes noise models contains 'Noise'
cells(1)={'Calculate'};
cellno=2;
for i=1:length(ex.tfplist),
    if (length(findstr(ex.tfplist{i}.name, 'Noise'))>0) 
	cells(cellno)={ex.tfplist{i}.name};
	cellno=cellno+1;
    end;
end
models=str2mat(char(cells));                                                 
