function lclist = setupLClist()
%% ===========================================================================
%setupLClist - Define a default theoretical line code model.
%
% Returns:      lclist		A list of structures describing time and
%                               frequency plans
%
% Example(s):
%    lclist = setupLClist; 
%
% Algorithmic details:
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Bo Engstrom (bosse@upzide.com)
%
% CVS:       $Id: setupLClist.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-10-01 (DaB) Created
%      2000-01-12 (DaB)  lc function changed
%      2000-01-12 (DaB) xtalk_margin added and Px
%      2000-04-04 (DaB) signal_margin added
%      2001-06-14 (Bosse) Octave port
%      2002-07-01 (PeKa) Octave to Matlab compatibility port
%      2002-10-09 (ToNo) Implemented two-sided power constraints
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%      2003-12-16 (ToNo) Split background noise into bgNoise and modemNoise
%% ===========================================================================

% Default Parameter values
def_param.signal_margin  = 0;
def_param.xtalk_margin   = 6;
def_param.refSNR         = 9.8;
def_param.codingGain     = 3.5;
def_param.SNRloss        = 0;


def_param.efficiencyLoss = 0.1;
def_param.SNRMax         = 60;
def_param.PxDown         = 11.5;
def_param.PxUp           = 11.5;

def_param.modemNoise.LT  = '-140'; % Modem noise at LT (dBm/Hz)
def_param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)

% VDSL Theoretical params 
tmp_lc.name	         = 'VDSL-theo';
tmp_lc.param	         = def_param;
tmp_lc.calcRate          = 'calcResultTheo';
tmp_lc.lcPrint 	         = 'lcPrintTheo';

lclist{1}=tmp_lc;



