function clist = ansi_cablesADSL(clist)
%% ===========================================================================
%ansi_cablesADSL(clist) - Sets up the cable models for ANSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist   = ansi_cablesADSL(ex.clist);             % Add to existing clist
%   cableparam = getList(ex.clist,'ANSI-ADSL-24AWG');  % Get the 24 AWG cable
%
% Reference:
%   ANSI Spectrum Compatibility T1.417 issue 2 (ANSI T1E1/2003-002R3)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: ansi_cablesADSL.m 556 2004-12-30 15:37:50Z tono $
%% ===========================================================================
% Change History
%      2000-09-09 (ToNo) Created to support G.996.1
%      2002-03-18 (ToNo) Switched to parametric model instead of the tables
%      2005-03-08 (ToNo) Updated to the values in the ANSI std.
%% ===========================================================================

% Note that in ansi_cablesVDSL.m these cables are also defined.
% However, with another accuracy.

%% ===========================================================================
% ANSI SpM cables

% 22-AWG 
cable=[];
cable.name='ANSI-ADSL-22AWG';
cable.model='BT';
cable.param.r0c=1.0848739e2;
cable.param.r0s=0;
cable.param.ac=1.6115812e-2;
cable.param.as=0.0;
cable.param.l0=6.1310123e-4;
cable.param.loo=4.5261987e-4;
cable.param.b=9.756855e-1;
cable.param.fm=3.3219138e5;
cable.param.coo=5.1573811e-8;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=7.3190856e-11;
cable.param.ge=9.359087e-1;
clist=insertList(clist,cable);

% TP2 0.5 mm 24-AWG 
cable=[];
cable.name='ANSI-ADSL-24AWG';
cable.model='BT';
cable.param.r0c=174.559;
cable.param.r0s=0;
cable.param.ac=0.05307;
cable.param.as=0.0;
cable.param.l0=617.295e-6;
cable.param.loo=478.971e-6;
cable.param.b=1.15298;
cable.param.fm=553.760e3;
cable.param.coo=50e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=0.234875e-12;
cable.param.ge=1.38;
clist=insertList(clist,cable);

% TP1 0.4 mm 26-AWG 
cable=[];
cable.name='ANSI-ADSL-26AWG';
cable.model='BT';
cable.param.r0c=286.176;
cable.param.r0s=0;
cable.param.ac=0.14769620;
cable.param.as=0.0;
cable.param.l0=675.369e-6;
cable.param.loo=488.952e-6;
cable.param.b=0.929;
cable.param.fm=806.339e3;
cable.param.coo=49e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=43e-9;
cable.param.ge=0.7;
clist=insertList(clist,cable);

