function clist = cables_at(clist)
%% ===========================================================================
%cables_at(clist) - Sets up the cable models for cables used in Austria
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist   = cables_at(ex.clist);               % Add to existing clist
%   cableparam = getList(ex.clist,'AT_40');         % Get AT PE 0.4 cable
%
% Reference:
%   T. Nordstrm, "A model for an Austrian PE04 cable", ETSI TM6 033TD09r1
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2003-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: cables_at.m 556 2004-12-30 15:37:50Z tono $
%% ===========================================================================
% Change History
%      2003-10-03 (ToNo) Created to support the Austrian cable model(s)
%% ===========================================================================

cable.name='AT_40';
cable.model='MAR';

cable.param.R0     = 286;          % Roo/km
cable.param.Linf   = 6.45e-4;      % Linf/km
cable.param.a      = 1.34;         % (proximity factor)
cable.param.b      = 0;            % (proximity factor)
cable.param.c      = 0.146;        % (proximity factor)
cable.param.C1M    = 3.32e-8;      % Cp/km(@1MHz)
cable.param.delta  = 6.68e-3;      % Delta(constant)
clist=insertList(clist,cable);


cable.name='AT_40x';
cable.model='MAR';

vars=[286.321 6.44875e-4 1.33944 5.63424e-23 0.145707 3.31668e-8 0.00668243]; 
cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.b      = vars(4);      % (proximity factor)
cable.param.c      = vars(5);      % (proximity factor)
cable.param.C1M    = vars(6);      % Cp/km(@1MHz)
cable.param.delta  = vars(7);      % Delta(constant)
clist=insertList(clist,cable);
