function [fxparam,fhparam,N,K]=etsi_SDSLmodelParameters(sym,brate,down)
%% ===========================================================================
% etsi_SDSLmodelParameters - Generates a vector with SDSL Tx 
%                            signal model parameters
%
% Parameter:    sym 	True (1) if a symmetrical model
% Parameter:    brate	The bitrate in kbit/s
% Parameter:    down	True (1) if it is the downstream (LTU)
%
% Returns:      fxparam,fhparam,N,K
%
% Examples:
%   [fxparam,fhparam,N,K]=etsi_SDSLmodelParameters(1,256)
%
% References:
%   Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%   
%   ETSI TR 101 830-2,  Spectral management on metallic access
%   networks; Part 2: Technical  methods and performance
%   evaluations, m01p20a5  
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2005-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: activeVDSLf.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2005-01-13 (ToNo) Created
%% ===========================================================================

if sym
    fxparam=1; fhparam=0.5; N=6;
    if brate<2048e3
        K=7.86;
    else
        K=9.90;
    end
else
    N=7;
    if brate==2048e3
        if down
            fxparam=2; fhparam=0.4;   K=16.86;
        else
            fxparam=1; fhparam=0.5;   K=15.66;            
        end
    elseif brate==2304e3
        if down
            fxparam=2; fhparam=0.375; K=12.48;
        else
            fxparam=1; fhparam=0.5;   K=11.74;            
        end
    else
        error(sprintf('Invalid SDSL aymmetrical Tx mask with brate=%g',brate));
    end;    
end;
