function lclist = etsi_lcdefsADSL(lclist)
%% ===========================================================================
%etsi_lcdefsADSL(lclist) - Sets up the tfplan for ETSI HAM band
%
% Parameter:    lclist	        Structure describing line code dependent stuff
% Returns:      lclist		Structure describing line code dependent stuff
%
% Example(s):
%   ex.lclist = etsi_lcdefsADSL(ex.lclist);       Add to existing lclist
%   lc = getList(ex.lclist,'ETSI-ADSL_DMT');      Get ADSL DMT line code stuff
%
%   ex.lclist = etsi_lcdefsADSL([]);              Create a new lclist
%   lc = getList(ex.lclist,'ETSI-ADSL-ECoverPOTS'); Get EC ADSL used over POTS
%
% Reference:
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999 by Telia Research AB, Lulea, Sweden;
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: etsi_lcdefsADSL.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-10-26 (ToNo) Created
%      1999-11-04 (ToNo) Made it into a function
%      2003-11-27 (ToNo) Created a file with new SpM definitions
%      2003-12-02 (ToNo) Added support for lc dependent modem noise
%      2005-01-05 (ToNo) Merged new SpM definitions, plus name changes
%% ===========================================================================

% Basic ADSL DMT params
basic_lc=lcDefADSLDMT; %'ADSL-DMT'
lclist=insertList(lclist,basic_lc);

%% ===========================================================================
% Some numbers for SpM

basic_lc.name = 'ETSI-ADSL-DMT';
basic_lc.param.xtalk_margin   = 6;      % We use a cross-talk margin of 6dB
basic_lc.param.signal_margin  = 0;      % (and therefore no signal margin)
basic_lc.param.SNRloss        = 2;      % SNR loss
basic_lc.param.codingGain     = 3;      % Net Coding gain of 3dB

basic_lc.param.modemNoise.LT  = '-120'; % Modem noise at LT (dBm/Hz)
basic_lc.param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)

lclist=insertList(lclist,basic_lc);

%% ===========================================================================
% Now do all variants

tfp='ETSI-ADSL-ECoverPOTS';
tonesup=7:31;
tonesdown=[7:63,65:255];
PxDown=20.4;
PxUp=12.5;
%
tmp_lc=basic_lc;
tmp_lc.name = tfp;
tmp_lc.param.dmt.us.tones   = tonesup;
tmp_lc.param.dmt.ds.tones   = tonesdown;
tmp_lc.param.PxDown         = PxDown;
tmp_lc.param.PxUp           = PxUp;
tmp_lc.param.modemNoise.LT  = '-120'; % Modem noise at LT (dBm/Hz)
tmp_lc.param.modemNoise.NT  = '-120'; % Modem noise at NT (dBm/Hz)
lclist=insertList(lclist,tmp_lc);


tfp='ETSI-ADSL-ECoverISDN';
tonesup=33:63;
tonesdown=[33:95,97:255];
PxDown=19.9;
PxUp=13.3;
%
tmp_lc=basic_lc;
tmp_lc.name = tfp;
tmp_lc.param.dmt.us.tones   = tonesup;
tmp_lc.param.dmt.ds.tones   = tonesdown;
tmp_lc.param.PxDown         = PxDown;
tmp_lc.param.PxUp           = PxUp;
tmp_lc.param.modemNoise.LT  = '-120'; % Modem noise at LT (dBm/Hz)
tmp_lc.param.modemNoise.NT  = '-120'; % Modem noise at NT (dBm/Hz)
lclist=insertList(lclist,tmp_lc);


tfp='ETSI-ADSL-FDDoverPOTS';
tonesup=7:30;
tonesdown=[38:63,65:255];
PxDown=19.9;
PxUp=12.5;
%
tmp_lc=basic_lc;
tmp_lc.name = tfp;
tmp_lc.param.dmt.us.tones   = tonesup;
tmp_lc.param.dmt.ds.tones   = tonesdown;
tmp_lc.param.PxDown         = PxDown;
tmp_lc.param.PxUp           = PxUp;
tmp_lc.param.modemNoise.LT  = '-120'; % Modem noise at LT (dBm/Hz)
tmp_lc.param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)
lclist=insertList(lclist,tmp_lc);


tfp='ETSI-ADSL-FDDoverISDN';
tonesup=33:56;
tonesdown=[64:95,97:255];
PxDown=19.3;
PxUp=13.3;
%
tmp_lc=basic_lc;
tmp_lc.name = tfp;
tmp_lc.param.dmt.us.tones   = tonesup;
tmp_lc.param.dmt.ds.tones   = tonesdown;
tmp_lc.param.PxDown         = PxDown;
tmp_lc.param.PxUp           = PxUp;
tmp_lc.param.modemNoise.LT  = '-120'; % Modem noise at LT (dBm/Hz)
tmp_lc.param.modemNoise.NT  = '-140'; % Modem noise at NT (dBm/Hz)
lclist=insertList(lclist,tmp_lc);
