function lclist = etsi_lcdefsSDSL_SpecificRates_RC(lclist)
%% ===========================================================================
% etsi_lcdefsSDSL_SpecificRates_RC(lclist) - 
%       Sets up the tfplan for ETSI SDLS tfplans with specific
%       rates, this time with a setup as we used for rate calculations
%
% Parameter:    lclist	 Structure describing line code dependent stuff
% Returns:      lclist   Structure describing line code dependent stuff
%
% Example(s):
%   ex.lclist = etsi_lcdefsSDSL_SpecificRates_RC(ex.lclist);
%   lc = getList(ex.lclist,'ETSI-SDSL-RC-sym-1024');
%
% References:	
%   Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%% ===========================================================================

%% ===========================================================================
% Copyright (C): 
%           2003-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                      All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
% 
% CVS:       $Id: etsi_lcdefsSDSL_SecificRates.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2003-11-27 (ToNo) Created
%      2003-12-02 (ToNo) Added support for lc dependent modem noise
%      2004-01-13 (ToNo) Changed coding gain at 256 kbits/s (and below)
%      2005-04-27 (ToNo) Fixed support for Asymmetric SDSL
%% ===========================================================================

% ETSI "Symmetrical" SDSL params
basic_lc       = lcDefSDSL_sym;

lcname = 'ETSI-SDSL-RC-sym-256';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(18:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

lcname = 'ETSI-SDSL-RC-sym-512';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(18:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

lcname = 'ETSI-SDSL-RC-sym-1024';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(18:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

lcname = 'ETSI-SDSL-RC-sym-2048';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(18:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

lcname = 'ETSI-SDSL-RC-sym-2304';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(18:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

%% ===========================================================================

% ETSI SpM Part-2 updated "Asymmetrical" SDSL params
basic_lc       = lcDefSDSL_asym;

lcname = 'ETSI-SDSL-RC-asym-2048';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(19:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

lcname = 'ETSI-SDSL-RC-asym-2304';
tmp_lc=basic_lc;
tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(19:length(lcname)));
tmp_lc.name=lcname;
lclist=insertList(lclist,tmp_lc);

%% ===========================================================================

