function tfplist = etsi_masksVDSL(tfplist)
%% ===========================================================================
%etsi_masksVDSL(tfplist) - Sets up the tfplan for ETSI VDSL PSD masks
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_masksVDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'ETSI-VDSL-Template-E1-PcabA-M1');  Get this mask
%
%   ex.tfplist = etsi_masksVDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'ETSI-VDSL-Template-E1-Pex-P1-M2'); Get this mask
%
% Reference:
%   ETSI VDSL Part 1 TS 101-270-1 V2.0.8 (2003-03)  
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_masksVDSL.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-08-30 (DaB)  Created based on (V1.1.6) draft (1999-08)
%      1999-09-16 (ToNo) Changed Ex.D upstream masks
%      1999-10-06 (ToNo) Rewritten for new ex struct
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      1999-11-04 (ToNo) Made it into a function
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-04-11 (DaB)  Added sync
%      2000-05-26 (UvAn) Added possibilities to fix the bitrate 
%      2002-10-09 (ToNo) Renamed all masks to start with "ETSI-VDSL-Mask"    
%      2002-10-10 (ToNo) Updated for current (V2.0.2) draft
%      2003-03-07 (ToNo) Updated for current (V2.0.7) draft (2003-01)
%      2003-03-12 (ToNo) Updated for current (V2.0.8) draft (2003-03)
%      2003-11-28 (ToNo) Added some support for US0 usage (for SpM studies)
%      2004-01-12 (ToNo) Fixed according to version (V2.0.10) (2003-05)
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!
tmp_tfplan = templateTFP;


%% ===========================================================================
%%% 997 FTTCab

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-P-M1-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[2825, -100];
[3000, -80];
[3001, -61];
[5099, -61];
[5100, -82];
[5274, -102];
[5275, -112];
[6875, -112];
[6876, -102];
[7050, -82];
[7051, -61];
[11999, -61];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM1=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1U0-P-M1-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[4, -110];
[25, -40];
[138, -40];
[307, -90];
[482, -100];
[2825, -100];
[3000, -80];
[3001, -61];
[5099, -61];
[5100, -82];
[5274, -102];
[5275, -112];
[6875, -112];
[6876, -102];
[7050, -82];
[7051, -61];
[11999, -61];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM1U0=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-P-M2-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[2825, -100];
[3000, -80];
[3001, -54.8];
[5099, -57.1];
[5100, -82];
[5274, -102];
[5275, -112];
[6875, -112];
[6876, -102];
[7050, -82];
[7051, -58.5];
[10000, -60];
[11999, -60];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM2=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1U0-P-M2-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[4, -110];
[25, -40];
[138, -40];
[307, -90];
[482, -100];
[2825, -100];
[3000, -80];
[3001, -54.8];
[5099, -57.1];
[5100, -82];
[5274, -102];
[5275, -112];
[6875, -112];
[6876, -102];
[7050, -82];
[7051, -58.5];
[10000, -60];
[11999, -60];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM2U0=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));



%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-PcabB-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[770, -100];
[945, -80];
[946, -78.3];
[947.2, -74.8];
[949, -72];
[958, -67.1];
[1104, -61];
[1105, -61]; % V2.0.8
[2999, -61];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -61];
[7049, -61];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-PcabA-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[929, -100]; % TD05 specific
[1104, -80]; % TD05 specific
[1105, -61]; % TD05 specific
[2999, -61]; 
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -61];
[7049, -61];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-PcabB-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[770, -100];
[945, -80];
[946, -77.3];
[947.2, -73.8];
[949, -71];
[958, -66.1];
[1104, -60];
[1105, -60];   % V2.0.8
[1394, -51.4]; % V2.0.8
[2999, -54.8];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -57.1];
[7049, -58.5];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-PcabA-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[929, -100]; % TD05 specific
[1104, -80]; % TD05 specific
[1105, -60]; % TD05 specific
[1394, -51.4]; % V2.0.8
[2999, -54.8];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -57.1];
[7049, -58.5];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 



%% ===========================================================================
%% 997 FTTEx

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-Pex-P1-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -61];
[217, -61];
[256, -46.4]; % V2.0.8
[1254, -46.4];
[1677, -61];
[2999, -61];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -61];
[7049, -61];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];
tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1U0-Pex-P1-M1';
%---------------------------------------------------------------------------
tmp_tfplan.name=U;
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1U0);
tfplist=insertList(tfplist,tmp_tfplan); 

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-Pex-P1-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -61];
[217, -61];
[251, -48.2]; % V2.0.8
[1303, -48.2];
[1394, -51.4];
[2999, -54.8];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -57.1];
[7049, -58.5];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-Pex-P2-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -46.9]; % V2.0.8
[1265, -46.9];
[1677, -61];
[2999, -61];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -61];
[7049, -61];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1U0-Pex-P2-M1';
%---------------------------------------------------------------------------
tmp_tfplan.name=U;
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1U0);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1-Pex-P2-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -48.5]; % V2.0.8
[1314, -48.5];
[1394, -51.4];
[2999, -54.8];
[3000, -82];
[3174, -102];
[3175, -110];
[4925, -110];
[4926, -102];
[5100, -82];
[5101, -57.1];
[7049, -58.5];
[7050, -82];
[7224, -102];
[7225, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E1U0-Pex-P2-M2';
%---------------------------------------------------------------------------
tmp_tfplan.name=U;
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2U0);
tfplist=insertList(tfplist,tmp_tfplan); 


%% ===========================================================================
%% 998 FTTCab

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-P-M1-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[3575, -100];
[3750, -80];
[3751, -61];
[5199, -61];
[5200, -82];
[5374, -102];
[5375, -112];
[8325, -112];
[8326, -102];
[8500, -82];
[8501, -61];
[11999, -61];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM1=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2U0-P-M1-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[4, -110];
[25, -40];
[138, -40];
[307, -90];
[482, -100];
[3575, -100];
[3750, -80];
[3751, -61];
[5199, -61];
[5200, -82];
[5374, -102];
[5375, -112];
[8325, -112];
[8326, -102];
[8500, -82];
[8501, -61];
[11999, -61];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];

tabstr_upM1U0=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-P-M2-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[3575, -100];
[3750, -80];
[3751, -55.7];
[5199, -57.2];
[5200, -82];
[5374, -102];
[5375, -112];
[8325, -112];
[8326, -102];
[8500, -82];
[8501, -59.3];
[10000, -60];
[11999, -60];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];
tabstr_upM2=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2U0-P-M2-up';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[4, -110];
[25, -40];
[138, -40];
[307, -90];
[482, -100];
[3575, -100];
[3750, -80];
[3751, -55.7];
[5199, -57.2];
[5200, -82];
[5374, -102];
[5375, -112];
[8325, -112];
[8326, -102];
[8500, -82];
[8501, -59.3];
[10000, -60];
[11999, -60];
[12000, -82];
[12175, -102];
[12176, -112];
[30000, -112];
];
tabstr_upM2U0=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-PcabB-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[770, -100];
[945, -80];
[946, -78.3];
[947.2, -74.8];
[949, -72];
[958, -67.1];
[1104, -61];
[3749, -61];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -61];
[8499, -61];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-PcabA-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[929, -100]; % TD05 specific
[1104, -80]; % TD05 specific
[1105, -61]; % TD05 specific
[3749, -61];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -61];
[8499, -61];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-PcabB-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[770, -100];
[945, -80];
[946, -77.3];
[947.2, -73.8];
[949, -71];
[958, -66.1];
[1104, -60];
[1295, -54.12];
[2603, -54.12];
[3749, -55.7];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -57.2];
[8499, -59.3];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-PcabA-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -110];
[225, -110];
[226, -100];
[929, -100]; % TD05 specific
[1104, -80]; % TD05 specific
[1105, -60]; % TD05 specific
[1295, -54.1]; % V2.0.8
[2603, -54.1];
[3749, -55.7];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -57.2];
[8499, -59.3];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 



%% ===========================================================================
%% 998 FTTEx

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-Pex-P1-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -61];
[217, -61];
[255, -46.8];  % V2.0.8
[1262, -46.8];
[1677, -61];
[3749, -61];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -61];
[8499, -61];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-Pex-P1-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -61];
[217, -61];
[248, -49.4];  % V2.0.8
[1336, -49.4];
[1394, -51.4];
[3749, -55.7];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -57.2];
[8499, -59.3];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 

%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2U0-Pex-P2-M2';
%---------------------------------------------------------------------------
tmp_tfplan.name=U;
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2U0);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-Pex-P2-M1';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -47.2]; % V2.0.8
[1273, -47.2];
[1677, -61];
[3749, -61];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -61];
[8499, -61];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM1);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
U='ETSI-VDSL-Template-E2-Pex-P2-M2';
%---------------------------------------------------------------------------
table = [
[0.001, -97.5];
[3.99, -97.5];
[4, -90];
[138, -90];
[139, -49.7]; % V2.0.8
[1346, -49.7];
[1394, -51.4];
[3749, -55.7];
[3750, -82];
[3924, -102];
[3925, -110];
[5025, -110];
[5026, -102];
[5200, -82];
[5201, -57.2];
[8499, -59.3];
[8500, -82];
[8674, -102];
[8675, -112];
[30000, -112];
];

tmp_tfplan.name=U;
tabstr=num2str(reshape([table(:,1)*1e3,table(:,2)]',1,numel(table)));
tmp_tfplan.PSD.upstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr_upM2);
tmp_tfplan.PSD.downstream =sprintf('calcPSD([%s ],''Log-Linear'',ex.param.frequency.f)',tabstr);
tfplist=insertList(tfplist,tmp_tfplan); 


%---------------------------------------------------------------------------
