function tfplist = etsi_noisesADSL2plus(tfplist)
%% ===========================================================================
%etsi_noisesADSL2plus(tfplist) - Sets up the tfplans for some
%                                standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_noisesADSL2plus(ex.tfplist);     Add to existing tfplist
%   tfplan=getList(ex.tfplist,...
%                 'ETSI-ADSL2plus-AnnexA-NoiseA') ;    Get this ADSL noise
%
%   ex.tfplist = etsi_noisesADSL2plus([]);             Create a new tfplist
%   tfplan=getList(ex.tfplist,,...
%                 'ETSI-ADSL2plus-AnnexJ-NoiseB') ;    Get this ADSL noise
%
%  Noise definitions:
%    044w09.doc, NoiseADSL2plusv5.xls
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2005-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: etsi_noisesADSL2plus.m 568 2005-01-04 14:43:53Z tono $
%% ===========================================================================
% Change History
%      2005-04-29 (ToNo) Created
%      2005-05-nn (ToNo) Various updates based on Flavios' data (vers. 2-4)
%      2005-05-09 (ToNo) Updated to version 5 of Flavios' data
%% ===========================================================================

%% ===========================================================================
% Template, order important!

% Default values
def_tfplan = templateTFP;

%% ===========================================================================
% These noise PSDs are based on spreadsheets of data "NoiseADSL2plusv5.xls" 
% provided by Flavio Marigliano, TILAB to ETSI

% Note that NT = upstream

%% ========= NOISE A

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexA-NoiseA';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15e3 -20 30e3 -21.6 45e3 -24.1 60e3 -26.9 68e3 -27.6 137990 -27.9 138e3 -26.1 300e3 -27 470e3 -27.8 1106e3 -27.8 1622e3 -37.8 2208e3 -39.1 2.5e6 -50.7 3001500 -71.3 3175e3 -87.7 3750e3 -87.7 4e6 -91 4300e3 -94.3 4545e3 -96.2 7225e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15e3 -20 24e3 -20.9 30e3 -21 45e3 -23 60e3 -24.7 138e3 -24.9 151e3 -28 207e3 -28.7 300e3 -30.3 358e3 -32.8 407e3 -36.7 500e3 -48.6 594e3 -62.3 755e3 -62.3 1059e3 -73.7 1221e3 -75.5 1400e3 -77.9 1750e3 -85 2212e3 -92 2800e3 -96 5274e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexB-NoiseA';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15e3 -20 30e3 -21.5 44e3 -24.1 60e3 -26.9 68e3 -27.6 99e3 -27.6 200e3 -28.7 254e3 -29.5 255e3 -26.7 414e3 -27.8 1104e3 -27.8 1622e3 -37.8 2208e3 -39.1 2.5e6 -50.7 3e6 -71.3 3174e3 -87.8 3750e3 -87.8 4550e3 -96.2 7200e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20.1 15e3 -20 30e3 -21.5 45e3 -24.1 69e3 -27.6 108e3 -27.6 119e3 -24.8 276e3 -25.3 310e3 -30.6 400e3 -36.2 595e3 -62.4 755e3 -62.4 1082e3 -74.2 1183e3 -76.3 1400e3 -77.9 1750e3 -85 2212e3 -92 2800e3 -96 5274e3 -97.1 30e6 -97.1  ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexM-NoiseA';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15e3 -20 30e3 -21.5 44e3 -24.1 60e3 -26.9 68e3 -27.6 99e3 -27.6 200e3 -28.7 254e3 -29.5 255e3 -26.7 414e3 -27.8 1104e3 -27.8 1622e3 -37.8 2208e3 -39.1 2.5e6 -50.7 3e6 -71.3 3174e3 -87.8 3750e3 -87.8 4550e3 -96.2 7200e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20 15e3 -20 24e3 -21 30e3 -21.4 45e3 -23.7 60e3 -25.9 66e3 -26.3 99e3 -26.3 276e3 -27.5 301e3 -30.3 400e3 -36.2 595e3 -62.4 755e3 -62.4 1076e3 -74.1 1204e3 -76.6 1402e3 -77.9 2246e3 -92.4 2800e3 -96 3154e3 -96.6 5274e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexJ-NoiseA';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -20.1 15e3 -20 30e3 -21.5 44e3 -24.1 60e3 -26.9 68e3 -27.6 99e3 -27.6 200e3 -28.7 254e3 -29.5 255e3 -26.7 414e3 -27.8 1104e3 -27.8 1622e3 -37.8 2208e3 -39.1 2.5e6 -50.7 3e6 -71.3 3174e3 -87.8 3750e3 -87.8 4550e3 -96.2 7200e3 -97.1 30e6 -97.1  ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -20.1 2e3 -20.1 3e3 -20 15e3 -19.9 30e3 -21.4 45e3 -23.7 60e3 -25.9 66e3 -26.3 99e3 -26.3 276e3 -27.5 355e3 -32.8 380e3 -34.5 500e3 -48.6 595e3 -62.4 755e3 -62.4 980e3 -71.3 1128e3 -75.3 1402e3 -77.9 1750e3 -85.1 2e6 -89.2 2350e3 -93.5 2800e3 -96 5200e3 -97.1 30e6 -97.1 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);



%% ========= NOISE B

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexA-NoiseB';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15e3 -25.6 30e3 -27.1 45e3 -29.6 65e3 -32.6 137990 -32.8 138e3 -31.7 272e3 -32.6 414e3 -34.2 1103e3 -34.2 1622e3 -44.2 2208e3 -45.5 2.5e6 -57.1 3001500 -77.7 3175e3 -94.1 3750e3 -94.1 4e6 -97.2 4300e3 -100.2 4545e3 -101.6 7225e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 15e3 -25.6 24e3 -26.5 30e3 -26.8 61e3 -30.5 138e3 -30.8 149e3 -33 200e3 -33.5 308e3 -35.2 375e3 -38.5 456e3 -46.9 605e3 -68.4 755e3 -68.4 980e3 -77.3 1128e3 -80.8 1402e3 -83.7 1750e3 -90.8 2208e3 -97.6 2800e3 -101.4 5274e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexB-NoiseB';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15e3 -25.6 30e3 -27.1 45e3 -29.6 59e3 -32 66e3 -32.5 99e3 -32.6 200e3 -33.6 253e3 -34.3 254e3 -32.5 414e3 -34.2 1103e3 -34.2 1622e3 -44.2 2208e3 -45.5 2.5e6 -57.1 3e6 -77.7 3175e3 -94.1 3750e3 -94.1 4220e3 -99.5 4550e3 -101.6 7200e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 15e3 -25.6 30e3 -27.2 45e3 -29.6 70e3 -32.6 108e3 -32.7 119e3 -30.7 276e3 -31.4 310e3 -35.5 400e3 -41.1 605e3 -68.4 755e3 -68.4 1082e3 -80.2 1186e3 -82.2 1400e3 -83.7 1750e3 -90.8 2208e3 -97.6 2800e3 -101.4 5274e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexM-NoiseB';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15e3 -25.6 30e3 -27.1 45e3 -29.6 59e3 -32 66e3 -32.5 99e3 -32.6 200e3 -33.6 253e3 -34.3 254e3 -32.5 414e3 -34.2 1103e3 -34.2 1622e3 -44.2 2208e3 -45.5  2.5e6 -57.1 3e6 -77.7 3175e3 -94.1 3750e3 -94.1 4220e3 -99.5 4550e3 -101.6 7200e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.7 15e3 -25.6 24e3 -26.7 30e3 -27 65e3 -31.7 138e3 -32.1 276e3 -33.2 294e3 -34 340e3 -37 375e3 -38.5 456e3 -46.9 605e3 -68.4 755e3 -68.4 980e3 -77.3 1128e3 -81.3 1402e3 -83.7 1750e3 -90.8 2e6 -94.8 2350e3 -99.1 2700e3 -101.1 5200e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexJ-NoiseB';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -25.7 15e3 -25.6 30e3 -27.1 45e3 -29.6 59e3 -32 66e3 -32.5 99e3 -32.6 200e3 -33.6 253e3 -34.3 254e3 -32.5 414e3 -34.2 1103e3 -34.2 1622e3 -44.2 2208e3 -45.5 2500e3 -57.1 3e6 -77.7 3175e3 -94.1 3750e3 -94.1 4220e3 -99.5 4550e3 -101.6 7200e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -25.8 2e3 -25.8 3e3 -25.7 15e3 -25.6 30e3 -27 45e3 -29.3 60e3 -31.3 65e3 -31.7 99e3 -31.8 276e3 -33.2 355e3 -37.5 380e3 -39.3 500e3 -53.5 605e3 -68.4 755e3 -68.4 980e3 -77.3 1128e3 -81.2 1402e3 -83.7 1750e3 -90.8 2e6 -94.9 2350e3 -99.1 2700e3 -101.1 5200e3 -102.2 30e6 -102.2 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);


%% ========= NOISE D

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexA-NoiseD';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -90.9 3990 -90.9 4e3 -85.9 80e3 -65.9 137990 -37.6 138e3 -29.9 1104e3 -29.9 1622e3 -39.9 2208e3 -41.2 2500e3 -52.8 3001500 -73.4 3175e3 -89.9 3750e3 -89.9 4545e3 -99.9 7225e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -90.9 3990 -90.9 4e3 -85.9 25875 -27.9 138e3 -27.9 229600 -82.8 686e3 -89.9 1411e3 -89.9 1630e3 -99.9 5275e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexB-NoiseD';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 93100 -79.9 209e3 -55.4 253990 -41.9 254e3 -29.9 1104e3 -29.9 1622e3 -39.9 2208e3 -41.2 2500e3 -52.8 3001500 -73.4 3175e3 -89.9 3750e3 -89.9 4545e3 -99.9 7225e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -79.9 50e3 -79.9 80e3 -75.2 120e3 -27.9 276e3 -27.9 491e3 -87.7 686e3 -89.9 1411e3 -89.9 1630e3 -99.9 5275e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexM-NoiseD';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 93100 -79.9 209e3 -55.4 253990 -41.9 254e3 -29.9 1104e3 -29.9 1622e3 -39.9 2208e3 -41.2 2500e3 -52.8 3001500 -73.4 3175e3 -89.9 3750e3 -89.9 4545e3 -99.9 7225e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -90.9 3990 -90.9 4e3 -85.9 25875 -30.9 276e3 -30.9 475990 -87.5 686e3 -89.9 1411e3 -89.9 1630e3 -99.9 5275e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-ADSL2plus-AnnexJ-NoiseD';
tmp_tfplan.PSD.downstream= 'calcPSD([1 -79.9 93100 -79.9 209e3 -55.4 253990 -41.9 254e3 -29.9 1104e3 -29.9 1622e3 -39.9 2208e3 -41.2 2500e3 -52.8 3001500 -73.4 3175e3 -89.9 3750e3 -89.9 4545e3 -99.9 7225e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream= 'calcPSD([1 -39.9 1500 -39.9 3e3 -30.9 276e3 -30.9 475990 -87.5 686e3 -89.9 1411e3 -89.9 1630e3 -99.9 5275e3 -101.9 12e6 -101.9 30e6 -101.9 ] ,''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);
