function tfplist = itu_modelsPNT(tfplist)
%% ===========================================================================
%itu_modelsPNT(tfplist) - Sets up the tfplan for ITU alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = itu_modelsPNT(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'PNT');             Get the PNT mask
%
%   ex.tfplist = itu_modelsPNT([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'PNT-3dB');         Get the PNT mask (-3dB)
%
% Reference:
%    ITU SG15 Question 4/15 NT-G12
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999-2000 by Telia Research AB, Lulea, Sweden;
%       2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: itu_modelsPNT.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-11-05 (ToNo) Created
%      2000-04-05 (UvAn) Added frequency axis for the call to
%                        calcPSD and removed "global ex"
%      2002-08-23 (ToNo) Defined the template by calling a function
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!

def_tfplan = templateTFP;

%% ===========================================================================
% TFPlan  definitions starting
% -------------------------------

% ITU g.pnt
tmp_tfplan=def_tfplan;
tmp_tfplan.name='PNT'; 
tmp_tfplan.PSD.downstream='calcPSD([ 2.7e6 -140 3.5e6 -93.5 4.5e6 -73.5 7e6 -73.5 7e6 -83.5 7.3e6 -83.5 7.3e6 -73.5 9.5e6 -73.5 10e6 -83.5 11.5e6 -108.5 12e6 -123.5 12.5e6 -135 30e6 -135 30e6 -140],''Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
def_tfplan.PSD.active.upstream   = [2.7e6 12.5e6];
def_tfplan.PSD.active.downstream = [2.7e6 12.5e6];
tfplist=insertList(tfplist,tmp_tfplan);

% ITU g.pnt (-3dB)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='PNT-3dB'; 
tmp_tfplan.PSD.downstream='calcPSD([ 2.7e6 -140 3.5e6 -96.5 4.5e6 -76.5 7e6 -76.5 7e6 -86.5 7.3e6 -86.5 7.3e6 -76.5 9.5e6 -76.5 10e6 -86.5 11.5e6 -111.5 12e6 -126.5 12.5e6 -138 30e6 -138 30e6 -140],''Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
def_tfplan.PSD.active.upstream   = [2.7e6 12.5e6];
def_tfplan.PSD.active.downstream = [2.7e6 12.5e6];
tfplist=insertList(tfplist,tmp_tfplan);
