function lc = lcDefHDSL2B1Q
%% ===========================================================================
% lcDefHDSL - Sets up the lincode description structure for
%             HDSL/2B1Q
%
% Returns:       lc	The linecode structure
%
% References:	
%    ETSI TM6 m01p20a5
%    Chen W., "DSL simulation techniques and standards development
%    for DSL systems"
%    Starr T., J. Cioffi, P. Silverman "Understanding DSL technology", 1999
%    The xDSL simulation tool manual, FTW 2000
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2003-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: lcDefHDSL2B1Q.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2003-11-26 (ToNo) Created
%      2003-12-02 (ToNo) Added support for lc dependent modem noise
%% ===========================================================================

lc.name           	  = 'ETSI-HDSL-2B1Q-2p';

lc.param.signal_margin    = 0;
lc.param.xtalk_margin     = 6;

lc.param.refSNR           = 9.75;
lc.param.codingGain       = 0;  
lc.param.SNRloss          = 1.6;

bps                       = 2;        % 2B1Q

% Calculate the req SNR [Starr]:
M  = 2^(bps);
Pe = 1e-7;
ei = erfinv(1-Pe./(1-1./M));
lc.param.reqSNR           = 10*log10((M.*M-1).*2./3.*ei.^2) + ...
                           lc.param.SNRloss - lc.param.codingGain;

% or use refSNR
lc.param.reqSNR           = 10*log10(2^(2*bps)-1) + lc.param.refSNR + ...
                           lc.param.SNRloss - lc.param.codingGain;

% Param digital
lc.param.modulation       = 'PAM';  % Modulation is 2B1Q
lc.param.mod.bpsym        = bps;    % Bits per symbol
lc.param.mod.brate.rate   = 1024e3; % Bitrate in bit per sec. (excl. overhead)
lc.param.mod.brate.ohead  = 144e3;  % Datarate overhead

lc.param.SNRMax           = 100;    % Maximum SNR usable [Chen p.524] 
lc.param.efficiencyLoss   = 0;      % General efficiency loss factor
                                    % HDSL uses SNRloss instead

lc.param.modemNoise.LT    = '-140'; % Modem noise at LT (dBm/Hz)
lc.param.modemNoise.NT    = '-140'; % Modem noise at NT (dBm/Hz)

lc.calcRate 		  = 'calcResultHDSL';
lc.lcPrint 		  = 'lcPrintHDSL';
