function lc = lcDefHDSLCAP
%% ===========================================================================
% lcDefHDSL - Sets up the lincode description structure for
%             HDSL/CAP 2p
%
% Returns:       lc	The linecode structure
%
% References:	
%    ETSI TM6 m01p20a5
%    Chen W., "DSL simulation techniques and standards development
%    for DSL systems"
%    Starr T., J. Cioffi, P. Silverman "Understanding DSL technology", 1999
%    The xDSL simulation tool manual, FTW 2000
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2003-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: lcDefHDSLCAP.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2003-11-26 (ToNo) Created
%      2003-12-02 (ToNo) Added support for lc dependent modem noise
%% ===========================================================================

lc.name           	  = 'ETSI-HDSL-CAP-2p';

lc.param.signal_margin    = 0;
lc.param.xtalk_margin     = 6;

% This make this to Effective SNR-gap of 6.8dB
lc.param.refSNR           = 9.8;
lc.param.codingGain       = 4.5;  
lc.param.SNRloss          = 1.5;

bps                       = 5;      % CAP 2-pair

% Calculate the required SNR
lc.param.reqSNR = 10*log10(2.^(bps)-1) + lc.param.refSNR + ...
    lc.param.SNRloss - lc.param.codingGain;

% Param digital
lc.param.modulation       = 'CAP';  % Modulation is CAP
lc.param.mod.bpsym        = bps;    % Bits per symbol
lc.param.mod.brate.rate   = 1024e3; % Bitrate in bit per sec. (excl. overhead)
lc.param.mod.brate.ohead  = 144e3;  % Datarate overhead

lc.param.SNRMax           = 100;   % Maximum SNR usable [Chen p.524] 
lc.param.efficiencyLoss   = 0;     % General efficiency loss factor
                                   % HDSL uses SNRloss instead

lc.param.modemNoise.LT    = '-105'; % Modem noise at LT (dBm/Hz)
lc.param.modemNoise.NT    = '-105'; % Modem noise at NT (dBm/Hz)
                                   
lc.calcRate 		  = 'calcResultHDSL';
lc.lcPrint 		  = 'lcPrintHDSL';
