function lcPrintDMT(lc)
%% ===========================================================================
%lcPrintDMT - Print the lincode description structure for DMT
%
% Parameter:    lc     Line code structure to print
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2001-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcPrintDMT.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      1999-10-12 (ToNo) Created
%      2000-01-12 (DaB)  Modified
%      2000-04-04 (Dab)  Added signal margin
%      2001-07-03 (ToNo) Added active tones    
%      2002-10-09 (ToNo) Implemented two-sided power constraints
%      2003-12-18 (DrSt) Split "Param digital" in downstream and
%                        upstream parameters
%% ===========================================================================
fprintf('Line code name: %s\n',lc.name);


fprintf('SNR ref = %g dB, coding gain = %g dB, loss = %g dB, SNRmax = %g dB\n',...
lc.param.refSNR,...
lc.param.codingGain,...
lc.param.SNRloss,...
lc.param.SNRMax);
fprintf('xtalk_margin = %g dB, signal_margin = %g dB\n',...
lc.param.xtalk_margin,...
lc.param.signal_margin);

dmt = lc.param.dmt;

fprintf('Maximum Power DOWN = %g dBm, UP = %g dBm \n',...
        lc.param.PxDown,lc.param.PxUp);

%% ===========================================================================
% Parameter that are DMT specific
fprintf('Sample rate DS = %gMHz, Sample rate US = %gMHz\n',...
dmt.ds.fs/1e6, dmt.us.fs/1e6);

fprintf('Carriers DS = %d, Carriers US = %d, Carrier spacing = %g kHz\n',...
dmt.ds.carriers, dmt.us.carriers, ...
dmt.df/1e3);

fprintf('Tones used US:%d-%d; DS:%d-%d (#64=%d, #96=%d)\n',...
min(dmt.us.tones),max(dmt.us.tones) ,...
min(dmt.ds.tones),max(dmt.ds.tones) ,...
sum(dmt.ds.tones==64), ...
sum(dmt.us.tones==96));

fprintf('DMT structure\n');
fprintf('  DS:  cp =%3d,  cs =%3d,  my = %2d,  beta = %2d\n',...
dmt.ds.cp, dmt.ds.cs, dmt.ds.my, dmt.ds.beta);
fprintf('  US:  cp =%3d,  cs =%3d,  my = %2d,  beta = %2d\n',...
dmt.us.cp, dmt.us.cs, dmt.us.my, dmt.us.beta);

fprintf('Efficiency Loss = %2.2f%%\n',lc.param.efficiencyLoss*100);

fprintf('Constellation sizes between %d and %d\n',...
min(lc.param.constellation),max(lc.param.constellation));

