function P=modelPSD_HDSL(f)
%% ===========================================================================
% modelPSD_HDSL PSD mask for HDSL
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    T1E1.4/99 -438R2
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2000-2007 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_HDSL.m 685 2007-01-16 14:46:11Z tono $
%% ===========================================================================
% Change History
%      2000-07-10 (ToNo) Created
%      2003-11-30 (ToNo) Removed internal sinc function
%% ===========================================================================

Vp   = 2.7;     % V
R    = 135;     % Ohm
f0   = 392e3;   % Hz
f3dB = 196e3;   % Hz

P=(5/9)*(Vp*Vp/R)*(2/f0)*(sinc(f/f0)).^2./(1 + (f/f3dB).^8) * 1000; % mW
